@@ -2,7 +2,7 @@
 /*
  * gsf-input-gzip.h: wrapper to uncompress gzipped input
  *
- * Copyright (C) 2002-2004 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2006 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -22,7 +22,7 @@
 #ifndef GSF_INPUT_GZIP_H
 #define GSF_INPUT_GZIP_H
 
-#include "gsf-input.h"
+#include <gsf/gsf-input.h>
 
 G_BEGIN_DECLS
 
@@ -32,7 +32,9 @@ G_BEGIN_DECLS
 
 typedef struct _GsfInputGZip GsfInputGZip;
 
-GType	  gsf_input_gzip_get_type (void);
+GType gsf_input_gzip_get_type      (void) G_GNUC_CONST;
+/* void  gsf_input_gzip_register_type (GTypeModule *module); glib dynamic types are not thread safe */
+
 GsfInput *gsf_input_gzip_new	  (GsfInput *source, GError **err);
 
 G_END_DECLS
